all_text_types_3.pdf

## Metadata

Title | all_text_types_3.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\all_text_types_3.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230403055847+01'00'
PDF Metadata: modDate | D:20230403055847+01'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0
2. h2 :: Quo fugiat animi qui quia enim qui ipsa omnis.
3. h6 :: Ea officia dicta 33 sunt voluptatem.
4. h6 :: Ea placeat ipsam.
5. h6 :: Non unde quam ex modi eveniet?
6. h5 :: Et vero illo ex vitae nemo qui officia quibusdam!

#### Page 0

No images

Path: | content.0.[0,0].bbox
Type: | addition

Key | Old | New
x1 |  | 442.7200012207031
y1 |  | 93.25177764892578
y0 |  | 74.33587646484375
x0 |  | 72.02400207519531

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 504.8096923828125
y1 |  | 130.03219604492188
y0 |  | 108.1980209350586
x0 |  | 72.02400207519531

Path: | content.0.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 509.25994873046875
y1 |  | 152.718017578125
y0 |  | 131.2379913330078
x0 |  | 72.02400207519531

Path: | content.0.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 208.12466430664062
y1 |  | 177.469970703125
y0 |  | 168.469970703125
x0 |  | 72.02400207519531

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 286.2446594238281
y1 |  | 197.38995361328125
y0 |  | 188.38995361328125
x0 |  | 108.0199966430664

Path: | content.0.[5,5].bbox
Type: | addition

Key | Old | New
x1 |  | 141.13467407226562
y1 |  | 217.19000244140625
y0 |  | 208.19000244140625
x0 |  | 72.02400207519531

Path: | content.0.[6,6].bbox
Type: | addition

Key | Old | New
x1 |  | 284.6846618652344
y1 |  | 237.1099853515625
y0 |  | 228.1099853515625
x0 |  | 108.0199966430664

Path: | content.0.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 202.3646697998047
y1 |  | 256.94000244140625
y0 |  | 247.94000244140625
x0 |  | 72.02400207519531

Path: | content.0.[8,8].bbox
Type: | addition

Key | Old | New
x1 |  | 266.08465576171875
y1 |  | 276.739990234375
y0 |  | 267.739990234375
x0 |  | 108.0199966430664

Path: | content.0.[9,9].bbox
Type: | addition

Key | Old | New
x1 |  | 326.8299865722656
y1 |  | 306.0044860839844
y0 |  | 294.0044860839844
x0 |  | 72.02400207519531

Path: | content.0.[10,10].bbox
Type: | addition

Key | Old | New
x1 |  | 517.283447265625
y1 |  | 354.1080017089844
y0 |  | 321.1080017089844
x0 |  | 72.02400207519531

Path: | content.0.[11,11].bbox
Type: | addition

Key | Old | New
x1 |  | 420.64666748046875
y1 |  | 407.6349792480469
y0 |  | 368.9750061035156
x0 |  | 72.02400207519531

Path: | content.0.[12,12].bbox
Type: | addition

Key | Old | New
x1 |  | 357.07000732421875
y1 |  | 434.3099670410156
y0 |  | 423.7499694824219
x0 |  | 72.02400207519531

Path: | content.0.[13,13].bbox
Type: | addition

Key | Old | New
x1 |  | 507.23077392578125
y1 |  | 471.2422180175781
y0 |  | 449.40802001953125
x0 |  | 72.02400207519531

Path: | content.0.[14,14].bbox
Type: | addition

Key | Old | New
x1 |  | 471.9100036621094
y1 |  | 482.40802001953125
y0 |  | 472.4480285644531
x0 |  | 72.02400207519531

Path: | content.0.[15,15].bbox
Type: | addition

Key | Old | New
x1 |  | 399.544677734375
y1 |  | 551.0799560546875
y0 |  | 497.9884948730469
x0 |  | 90.02400207519531

Path: | content.0.[16,16].bbox
Type: | addition

Key | Old | New
x1 |  | 319.9599914550781
y1 |  | 577.2322387695312
y0 |  | 567.272216796875
x0 |  | 72.02400207519531

Path: | content.0.[17,17].bbox
Type: | addition

Key | Old | New
x1 |  | 494.080078125
y1 |  | 625.7122802734375
y0 |  | 592.3579711914062
x0 |  | 72.02400207519531

Path: | content.0.[18,18].bbox
Type: | addition

Key | Old | New
x1 |  | 424.98468017578125
y1 |  | 664.1499633789062
y0 |  | 641.246337890625
x0 |  | 90.02400207519531

Path: | content.0.[19,19].bbox
Type: | addition

Key | Old | New
x1 |  | 516.2401733398438
y1 |  | 701.4224243164062
y0 |  | 679.8379516601562
x0 |  | 72.02400207519531

Path: | content.0.[20,20].bbox
Type: | addition

Key | Old | New
x1 |  | 448.4146728515625
y1 |  | 726.0700073242188
y0 |  | 717.0700073242188
x0 |  | 72.02400207519531

Path: | content.0.[21,21].bbox
Type: | addition

Key | Old | New
x1 |  | 519.228271484375
y1 |  | 764.0980224609375
y0 |  | 742.6179809570312
x0 |  | 72.02400207519531

## Quo fugiat animi qui quia enim qui ipsa omnis.

Lorem ipsum dolor sit amet. Aut itaque consequuntur ab explicabo velit Aut ratione aut neque dolorem et maxime nemo ut velit placeat et galisum neque. Aut sint tenetur Et doloremque 33 beatae eius et cumque

mollitia aut sunt voluptatem est unde libero eum atque nisi. Id consequuntur culpaAut provident id quaerat asperiores eum asperiores incidunt et enim voluptatem.

###### Ea officia dicta 33 sunt voluptatem.

Ut doloribus repellat cum quidem repudiandae.

###### Ea placeat ipsam.

Est voluptatum sequi quo consequatur veniam.

###### Non unde quam ex modi eveniet?

Aut similique consequuntur ea odit atque.

##### Et vero illo ex vitae nemo qui officia quibusdam!

Ut inventore delenitiSed rerum qui repudiandae omnis est libero sapiente ut sint minima. Et corrupti cupiditate est quam vitaeut omnis sit galisum perferendis. Qui dolores expedita Quo eius et omnis accusantium. Est consequatur ametHic alias est maiores enim qui voluptatem fuga qui quis consectetur ut aperiam aliquam.

Est numquam beatae? Ut officiis maiores. Ut obcaecati iure At fugit voluptate. Ut doloribus consequatur sit modi quisquam aut aspernatur quisquam.

Qui iure accusantium et eligendi voluptas sit aliquam delectus.

Ex voluptatum dolore eum voluptatem omnis Est totam cum placeat aliquid ut sunt explicabo sed dolore incidunt? Aut sint nostrum Ea necessitatibus aut nobis doloribus. Et molestiae voluptas et corporis

doloribusquo totam eos delectus illo aut velit enim. Et consectetur ducimusQui quia id alias libero.

1. A autem laborum qui dolorem sunt.

2. Qui amet deleniti ea sapiente molestiae aut natus quasi sit aliquam numquam.

3. Sed dignissimos voluptates ab earum nesciunt aut tenetur pariatur.

4. Qui consequatur error sit accusantium quibusdam eos tempora itaque.

5. Aut fuga illum aut facere reprehenderit est maiores voluptas.

Et deserunt iusto est minus officia sed tempore voluptas?

Sed quia quia qui quos quaeEum fuga non consequatur molestias est veniam magni qui rerum nemo. Sed quibusdam recusandae A odit sed ratione rerum vel consectetur laborum. Sed saepe quam ad voluptas doloremque Ea mollitia quo quibusdam galisum qui temporibus libero et nisi explicabo.

- Qui commodi nemo qui molestiae numquam.

- Ut iure tenetur ut veritatis autem non exercitationem assumenda est placeat dolores.

Vel quia teneturSit dolorem ut incidunt itaque et modi natus et cumque quidem ex aliquam voluptates. Et fugit autem Sed eligendi ad rerum possimus.

Est amet itaque sed odio atque At fuga sunt eos deleniti autem aut iure blanditiis et dicta voluptatem.

Ut dolores evenietQui recusandae quo corporis illum ut nemo velit vel amet quibusdam aut dolorum nobis. Aut voluptas ipsa ut mollitia consequunturnam temporibus aut labore laboriosam.

## Quo fugiat animi qui quia enim qui ipsa omnis.

Lorem ipsum dolor sit amet. Aut itaque consequuntur ab explicabo velit Aut ratione aut neque dolorem et maxime nemo ut velit placeat et galisum neque. Aut sint tenetur Et doloremque 33 beatae eius et cumque

mollitia aut sunt voluptatem est unde libero eum atque nisi. Id consequuntur culpaAut provident id quaerat asperiores eum asperiores incidunt et enim voluptatem.

###### Ea officia dicta 33 sunt voluptatem.

Ut doloribus repellat cum quidem repudiandae.

###### Ea placeat ipsam.

Est voluptatum sequi quo consequatur veniam.

###### Non unde quam ex modi eveniet?

Aut similique consequuntur ea odit atque.

##### Et vero illo ex vitae nemo qui officia quibusdam!

Ut inventore delenitiSed rerum qui repudiandae omnis est libero sapiente ut sint minima. Et corrupti cupiditate est quam vitaeut omnis sit galisum perferendis. Qui dolores expedita Quo eius et omnis accusantium. Est consequatur ametHic alias est maiores enim qui voluptatem fuga qui quis consectetur ut aperiam aliquam.

Est numquam beatae? Ut officiis maiores. Ut obcaecati iure At fugit voluptate. Ut doloribus consequatur sit modi quisquam aut aspernatur quisquam.

Qui iure accusantium et eligendi voluptas sit aliquam delectus.

Ex voluptatum dolore eum voluptatem omnis Est totam cum placeat aliquid ut sunt explicabo sed dolore incidunt? Aut sint nostrum Ea necessitatibus aut nobis doloribus. Et molestiae voluptas et corporis

doloribusquo totam eos delectus illo aut velit enim. Et consectetur ducimusQui quia id alias libero.

1. A autem laborum qui dolorem sunt.

2. Qui amet deleniti ea sapiente molestiae aut natus quasi sit aliquam numquam.

3. Sed dignissimos voluptates ab earum nesciunt aut tenetur pariatur.

4. Qui consequatur error sit accusantium quibusdam eos tempora itaque.

5. Aut fuga illum aut facere reprehenderit est maiores voluptas.

Et deserunt iusto est minus officia sed tempore voluptas?

Sed quia quia qui quos quaeEum fuga non consequatur molestias est veniam magni qui rerum nemo. Sed quibusdam recusandae A odit sed ratione rerum vel consectetur laborum. Sed saepe quam ad voluptas doloremque Ea mollitia quo quibusdam galisum qui temporibus libero et nisi explicabo.

- Qui commodi nemo qui molestiae numquam.

- Ut iure tenetur ut veritatis autem non exercitationem assumenda est placeat dolores.

Vel quia teneturSit dolorem ut incidunt itaque et modi natus et cumque quidem ex aliquam voluptates. Et fugit autem Sed eligendi ad rerum possimus.

Est amet itaque sed odio atque At fuga sunt eos deleniti autem aut iure blanditiis et dicta voluptatem.

Ut dolores evenietQui recusandae quo corporis illum ut nemo velit vel amet quibusdam aut dolorum nobis. Aut voluptas ipsa ut mollitia consequunturnam temporibus aut labore laboriosam.

Parent File Contents